Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(150)

Unified Diff: src/core/SkPMFloat.h

Issue 1055123002: New names for SkPMFloat methods. (Closed) Base URL: https://skia.googlesource.com/skia@master
Patch Set: one more Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bench/PMFloatBench.cpp ('k') | src/core/SkXfermode.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkPMFloat.h
diff --git a/src/core/SkPMFloat.h b/src/core/SkPMFloat.h
index 84c05ea762f7cd4afd9f24586d9a263ebd231622..bf7e66986045c84a36df171dd9bc908cccd1d912 100644
--- a/src/core/SkPMFloat.h
+++ b/src/core/SkPMFloat.h
@@ -45,18 +45,18 @@ public:
// N.B. All methods returning an SkPMColor call SkPMColorAssert on that result before returning.
- // get() and clamped() round component values to the nearest integer.
- SkPMColor get() const; // Assumes all values in [0, 255]. Some implementations may clamp.
- SkPMColor clamped() const; // Will clamp all values to [0, 255].
+ // round() and roundClamp() round component values to the nearest integer.
+ SkPMColor round() const; // Assumes all values in [0, 255]. Some implementations may clamp.
+ SkPMColor roundClamp() const; // Will clamp all values to [0, 255].
- // Like get(), but truncates instead of rounding.
+ // Like round(), but truncates instead of rounding.
// The domain of this function is (-1.0f, 256.0f). Values in (-1.0f, 0.0f] trunc to a zero.
SkPMColor trunc() const;
- // 4-at-a-time versions of get() and clamped(). Like From4PMColors(), no alignment assumed.
- static void To4PMColors(
+ // 4-at-a-time versions of round() and roundClamp(). Like From4PMColors(), no alignment assumed.
+ static void RoundTo4PMColors(
const SkPMFloat&, const SkPMFloat&, const SkPMFloat&, const SkPMFloat&, SkPMColor[4]);
- static void ClampTo4PMColors(
+ static void RoundClampTo4PMColors(
const SkPMFloat&, const SkPMFloat&, const SkPMFloat&, const SkPMFloat&, SkPMColor[4]);
bool isValid() const {
« no previous file with comments | « bench/PMFloatBench.cpp ('k') | src/core/SkXfermode.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698